@@ -15,7 +15,7 @@ use JSON::backportPP::Boolean;
 use Carp ();
 #use Devel::Peek;
 
-$JSON::backportPP::VERSION = '2.91_01';
+$JSON::backportPP::VERSION = '2.91_02';
 
 @JSON::PP::EXPORT = qw(encode_json decode_json from_json to_json);
 
@@ -410,7 +410,7 @@ sub allow_bigint {
         if (USE_B) {
             my $b_obj = B::svref_2object(\$value);
             my $flags = $b_obj->FLAGS;
-            return 1 if $flags & ( B::SVp_IOK | B::SVp_NOK ) and !( $flags & B::SVp_POK );
+            return 1 if $flags & ( B::SVp_IOK() | B::SVp_NOK() ) and !( $flags & B::SVp_POK() );
             return;
         } else {
             no warnings 'numeric';
